@@ -25,14 +25,18 @@
 #include <kaboutdata.h>
 #include <QApplication>
 #include <QUrl>
+#include <QDebug>
 
 #include <KDBusService>
 #include <KLocalizedString>
 #include <stdio.h>
-#include <KCrash/KCrash>
+#include <iostream>
+
+#include <KCrash>
 #include <QCommandLineParser>
 #include <QCommandLineOption>
 #include <QIcon>
+
 int main(int argc, char **argv)
 {
     QCoreApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
@@ -59,10 +63,22 @@ int main(int argc, char **argv)
     parser.addOption(QCommandLineOption(QStringList() <<  QStringLiteral("type"), i18n("Only offer accounts that support the given type."), QStringLiteral("type")));
     parser.addOption(QCommandLineOption(QStringList() <<  QStringLiteral("assistant"), i18n("Run the specified assistant."), QStringLiteral("assistant")));
     parser.addOption(QCommandLineOption(QStringList() <<  QStringLiteral("package"), i18n("unpack fullpath on startup and launch that assistant"), QStringLiteral("fullpath")));
+    parser.addOption(QCommandLineOption(QStringList() <<  QStringLiteral("assistants"), i18n("Returns types of assistants")));
+
 
     aboutData.setupCommandLine(&parser);
     parser.process(app);
     aboutData.processCommandLine(&parser);
+
+    if (parser.isSet(QStringLiteral("assistants"))) {
+        const QStringList lst = Global::assistants();
+        std::cout << i18n("The following assistants are available:").toLocal8Bit().data() << std::endl;
+        for (const QString &val : lst) {
+            std::cout << "\t" << val.toLocal8Bit().constData() << std::endl;
+        }
+        return 0;
+    }
+
     KDBusService service(KDBusService::Unique);
 
     Akonadi::ControlGui::start(nullptr);
