@@ -38,14 +38,7 @@
 
 SetupManager::SetupManager(QWidget *parent)
     : QObject(parent)
-    , m_currentSetupObject(nullptr)
-    , m_page(nullptr)
-    , m_wallet(nullptr)
     , m_keyPublishingMethod(Key::NoPublishing)
-    , m_personalDataAvailable(false)
-    , m_rollbackRequested(false)
-    , m_pgpAutoSign(false)
-    , m_pgpAutoEncrypt(false)
 {
     KEMailSettings e;
     m_name = e.getSetting(KEMailSettings::RealName);
@@ -102,12 +95,12 @@ QObject *SetupManager::createKey()
     return connectObject(key);
 }
 
-QList<SetupObject *> SetupManager::objectsToSetup() const
+QVector<SetupObject *> SetupManager::objectsToSetup() const
 {
     return m_objectToSetup;
 }
 
-QList<SetupObject *> SetupManager::setupObjects() const
+QVector<SetupObject *> SetupManager::setupObjects() const
 {
     return m_setupObjects;
 }
